@@ -33,5 +33,9 @@ class Archive(object):
     def generate_url(self, content_hash, file_name=None, mime_type=None, expire=None):
         return None
 
-    def publish_file(self, file_path, publish_path, bucket=None, mime_type=None):
+    @property
+    def can_publish(self):
+        return False
+
+    def publish_file(self, file_path, publish_path, mime_type=None):
         return None
