@@ -2,6 +2,7 @@ import multiprocessing
 from servicelayer import env
 
 # Redis cache
+# URL format: redis://localhost:6379/0
 REDIS_URL = env.get("REDIS_URL")
 REDIS_SHORT = 84700
 REDIS_LONG = REDIS_SHORT * 200
@@ -31,3 +32,15 @@ PUBLICATION_BUCKET = env.get("PUBLICATION_BUCKET", ARCHIVE_BUCKET)
 
 # Logging
 LOG_FORMAT = env.get("LOG_FORMAT", "TEXT")  # options are: TEXT or JSON
+
+# Task queue
+RABBITMQ_URL = env.get("RABBITMQ_URL", "rabbitmq")
+RABBITMQ_USERNAME = env.get("RABBITMQ_USERNAME", "guest")
+RABBITMQ_PASSWORD = env.get("RABBITMQ_PASSWORD", "guest")
+RABBITMQ_HEARTBEAT = env.to_int("RABBITMQ_HEARTBEAT", 600)
+RABBITMQ_BLOCKED_CONNECTION_TIMEOUT = env.to_int(
+    "RABBITMQ_BLOCKED_CONNECTION_TIMEOUT", 300
+)
+QUEUE_ALEPH = "aleph_queue"
+QUEUE_INGEST = "ingest_queue"
+QUEUE_INDEX = "index_queue"
