@@ -1,6 +1,6 @@
-import sys
 import signal
 import logging
+import sys
 from threading import Thread
 from banal import ensure_list
 from abc import ABC, abstractmethod
@@ -12,6 +12,13 @@ from servicelayer.util import unpack_int
 
 log = logging.getLogger(__name__)
 
+# When a worker thread is not blocking, it has to exit if no task is available.
+# `TASK_FETCH_RETRY`` determines how many times the worker thread will try to fetch
+# a task before quitting.
+# `INTERVAL`` determines the interval in seconds between each retry.
+INTERVAL = 2
+TASK_FETCH_RETRY = 60 / INTERVAL
+
 
 class Worker(ABC):
     """Workers of all microservices, unite!"""
@@ -20,26 +27,34 @@ class Worker(ABC):
         self.conn = conn or get_redis()
         self.stages = stages
         self.num_threads = num_threads
-        self._shutdown = False
+        self.exit_code = 0
 
-    def shutdown(self, *args):
-        log.warning("Shutting down worker.")
-        self._shutdown = True
-        if not self.num_threads:
-            sys.exit(23)
+    def _handle_signal(self, signal, frame):
+        log.warning(f"Shutting down worker (signal {signal})")
+        self.exit_code = int(signal)
+        # Exit eagerly without waiting for current task to finish running
+        sys.exit(self.exit_code)
 
     def handle_safe(self, task):
         try:
             self.handle(task)
-        except (SystemExit, KeyboardInterrupt, Exception):
+        except SystemExit as exc:
+            self.exit_code = exc.code
             self.retry(task)
-            raise
+        except KeyboardInterrupt:
+            self.exit_code = 23
+            self.retry(task)
+        except Exception:
+            if 0 == self.exit_code:
+                self.exit_code = 23
+            self.retry(task)
+            log.exception("Error in task handling")
         finally:
             task.done()
             self.after_task(task)
 
     def init_internal(self):
-        self._shutdown = False
+        self.exit_code = 0
         self.boot()
 
     def retry(self, task):
@@ -49,45 +64,51 @@ class Worker(ABC):
             task.context["retries"] = retries + 1
             task.stage.queue(task.payload, task.context)
 
-    def process(self, interval=5):
-        while True:
-            if self._shutdown:
-                return
+    def process(self, blocking=True, interval=INTERVAL):
+        retries = 0
+        while retries <= TASK_FETCH_RETRY:
+            if self.exit_code > 0:
+                log.info("Worker thread is exiting")
+                return self.exit_code
             self.periodic()
             stages = self.get_stages()
             task = Stage.get_task(self.conn, stages, timeout=interval)
             if task is None:
+                if not blocking:
+                    # If we get a null task, retry to fetch a task a bunch of times before quitting
+                    if retries >= TASK_FETCH_RETRY:
+                        log.info("Worker thread is exiting")
+                        return self.exit_code
+                    else:
+                        retries += 1
                 continue
+            # when we get a good task, reset retry count
+            retries = 0
             self.handle_safe(task)
 
     def sync(self):
         """Process only the tasks already in the job queue, but do not
         go into an infinte loop waiting for new ones."""
         self.init_internal()
-        while True:
-            stages = self.get_stages()
-            task = Stage.get_task(self.conn, stages, timeout=None)
-            if task is None:
-                return
-            self.handle_safe(task)
+        self.process(blocking=False, interval=None)
 
-    def run(self):
-        # Try to quit gracefully, e.g. after finishing the current task.
-        signal.signal(signal.SIGINT, self.shutdown)
-        signal.signal(signal.SIGTERM, self.shutdown)
+    def run(self, blocking=True, interval=INTERVAL):
+        signal.signal(signal.SIGINT, self._handle_signal)
+        signal.signal(signal.SIGTERM, self._handle_signal)
         self.init_internal()
+        process = lambda: self.process(blocking=blocking, interval=interval)
         if not self.num_threads:
-            return self.process()
+            return process()
         log.info("Worker has %d threads.", self.num_threads)
         threads = []
         for _ in range(self.num_threads):
-            thread = Thread(target=self.process)
+            thread = Thread(target=process)
             thread.daemon = True
             thread.start()
             threads.append(thread)
         for thread in threads:
             thread.join()
-        sys.exit(23)
+        return self.exit_code
 
     def get_stages(self):
         """Easily allow the user to make the active stages dynamic."""
