@@ -1,11 +1,15 @@
 from unittest import TestCase
+import pytest
 
 from servicelayer.cache import get_fakeredis
 from servicelayer.jobs import Job
-from servicelayer.worker import Worker
+from servicelayer import worker
 
 
-class CountingWorker(Worker):
+worker.TASK_FETCH_RETRY = 1
+
+
+class CountingWorker(worker.Worker):
     def boot(self):
         self.test_done = 0
 
@@ -32,7 +36,20 @@ class WorkerTest(TestCase):
         assert not job.is_done()
         worker.sync()
         assert job.is_done()
+        assert worker.exit_code == 0, worker.exit_code
         assert worker.test_done == 1, worker.test_done
-        worker.shutdown()
         worker.retry(task)
-        worker.process()
+        worker.run(blocking=False)
+        assert job.is_done()
+        assert worker.exit_code == 0, worker.exit_code
+        worker.num_threads = None
+        worker.retry(task)
+        worker.run(blocking=False)
+        assert job.is_done()
+        assert worker.exit_code == 0, worker.exit_code
+        try:
+            worker._handle_signal(5, None)
+        except SystemExit as exc:
+            assert exc.code == 5, exc.code
+        with pytest.raises(SystemExit) as exc:  # noqa
+            worker._handle_signal(5, None)
